function varargout = gui_minterm03(varargin)
% GUI_MINTERM03 MATLAB code for gui_minterm03.fig
%      GUI_MINTERM03, by itself, creates a new GUI_MINTERM03 or raises the existing
%      singleton*.
%
%      H = GUI_MINTERM03 returns the handle to a new GUI_MINTERM03 or the handle to
%      the existing singleton*.
%
%      GUI_MINTERM03('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in GUI_MINTERM03.M with the given input arguments.
%
%      GUI_MINTERM03('Property','Value',...) creates a new GUI_MINTERM03 or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before gui_minterm03_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to gui_minterm03_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help gui_minterm03

% Last Modified by GUIDE v2.5 29-Jan-2015 09:37:02

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @gui_minterm03_OpeningFcn, ...
                   'gui_OutputFcn',  @gui_minterm03_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before gui_minterm03 is made visible.
function gui_minterm03_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to gui_minterm03 (see VARARGIN)

% Choose default command line output for gui_minterm03
handles.output = hObject;
set(gca,'xtick',[],'ytick',[])
handles.minterms = [0 1];
set(handles.edit_minterms,'String',num2str(handles.minterms))
%set(handles.edit_minterms,'String',handles.edit_minterms)
% Update handles structure
guidata(hObject, handles);

% UIWAIT makes gui_minterm03 wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = gui_minterm03_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;

function edit_minterms_Callback(hObject, eventdata, handles)
% hObject    handle to edit_minterms (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_minterms as text
%        str2double(get(hObject,'String')) returns contents of edit_minterms as a double
data = str2num(get(hObject,'String'));
handles.minterms = sort(data);
set(handles.edit_minterms,'string',num2str(handles.minterms));
guidata(hObject, handles);

% --- Executes during object creation, after setting all properties.
function edit_minterms_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_minterms (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

% --- Executes on button press in push_eval.
function push_eval_Callback(hObject, eventdata, handles)
% hObject    handle to push_eval (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
[out] = show_terms_abcx(handles.minterms);
axes(handles.axes1)
%figure
plot(0,0)
%axes('PlotBoxAspectRatio',[2 4 2])
minterms = [0 1 2 3 4 5 6 7]';
outd = double(out);
outd = [minterms outd];
outa = num2str(outd);
header = 'm  a  b  c  f'
output = [header;outa];
text(-.9,0,output,'FontSize',24,'FontWeight','demi')
set(gca,'xtick',[],'ytick',[])
